@@ -11,7 +11,7 @@ use Getopt::Std;
 use Lingua::Translit;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -31,6 +31,7 @@ sub run {
 	# Process arguments.
 	$self->{'_opts'} = {
 		'h' => 0,
+		'r' => 0,
 		't' => 'ISO/R 9',
 	};
 	if (! getopts('hrt:', $self->{'_opts'}) || @ARGV < 1
@@ -165,11 +166,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2015 Michal Špaček
+ © 2015-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
